==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QSurface_shell.cpp <==
#include "QSurface_shell.h"
#include <QtJambi/Cast>

void deleter_QSurface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSurface")
    QSurface *_ptr = reinterpret_cast<QSurface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSurface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSurface_shell) ); }

jmethodID QSurface_shell::__shell_javaMethod(int pos) const { return QSurface_shell::__shell()->javaMethod(typeid(QSurface), pos); }

// emitting (writeShellConstructor)
// emitting (writeShellDestructor)
QSurface_shell::~QSurface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSurface::~QSurface()", QSurface_shell::__shell())
    QSurface_shell::__shell()->destructed(typeid(QSurface));
}

void QSurface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSurface_shell*>(ptr)->QSurface_shell::__shell()->tryDeleteShell(typeid(QSurface));
}

// emitting Virtual overrides (virtualFunctions)
QSurfaceFormat QSurface_shell::format() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSurface::", QSurface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QSurfaceFormat  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QSurface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QSurfaceFormat >(__jni_env, __java_return_value);
                } else {
                    QSurface_shell::__shell()->warnForMethod("QSurface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSurface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSurfaceFormat();
        }
    }else{
        return QSurfaceFormat();
    }
}

QSize QSurface_shell::size() const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QSurface::", QSurface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QSize  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QSurface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QSize >(__jni_env, __java_return_value);
                } else {
                    QSurface_shell::__shell()->warnForMethod("QSurface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSurface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSize();
        }
    }else{
        return QSize();
    }
}

QSurface::SurfaceType QSurface_shell::surfaceType() const
{
    if(jmethodID method_id = __shell_javaMethod(2)){
        QTJAMBI_JAVA_METHOD_CALL("QSurface::", QSurface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QSurface::SurfaceType  __qt_return_value = QSurface::SurfaceType(0);
            QTJAMBI_TRY {
                if(jobject __java_this = QSurface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QSurface::SurfaceType>(__jni_env, __java_return_value);
                } else {
                    QSurface_shell::__shell()->warnForMethod("QSurface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSurface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSurface::SurfaceType(0);
        }
    }else{
        return QSurface::SurfaceType(0);
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QSurface_access::__qt_format_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QSurface::format() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QSurface::format() const.";
    } else {
        QSurfaceFormat __qt_return_value = format();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

jobject QSurface_access::__qt_size_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QSurface::size() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QSurface::size() const.";
    } else {
        QSize __qt_return_value = size();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

jint QSurface_access::__qt_surfaceType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QSurface::surfaceType() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QSurface::surfaceType() const.";
    } else {
        QSurface::SurfaceType __qt_return_value = surfaceType();
        return __qt_return_value;
    }
}

// emitting (writeConstructors)
// destruct QSurface_shell
void __qt_destruct_QSurface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSurface")
    reinterpret_cast<QSurface_shell*>(ptr)->~QSurface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSurface::supportsOpenGL()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QSurface_00024Impl_supportsOpenGL_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QSurface *__qt_this = QtJambiAPI::interfaceFromNativeId<QSurface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSurface::supportsOpenGL()const", __qt_this)
        __java_return_value = __qt_this->QSurface::supportsOpenGL();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSurface::format()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QSurface_00024Impl_00024ConcreteWrapper_format_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSurface *__qt_this = QtJambiAPI::interfaceFromNativeId<QSurface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSurface::format()const", __qt_this)
        __java_return_value = static_cast<const QSurface_access*>(__qt_this)->__qt_format_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSurface::size()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QSurface_00024Impl_00024ConcreteWrapper_size_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSurface *__qt_this = QtJambiAPI::interfaceFromNativeId<QSurface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSurface::size()const", __qt_this)
        __java_return_value = static_cast<const QSurface_access*>(__qt_this)->__qt_size_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSurface::surfaceType()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QSurface_00024Impl_00024ConcreteWrapper_surfaceType_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QSurface *__qt_this = QtJambiAPI::interfaceFromNativeId<QSurface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSurface::surfaceType()const", __qt_this)
        __java_return_value = static_cast<const QSurface_access*>(__qt_this)->__qt_surfaceType_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSurface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QSurface>("QSurface", "io/qt/gui/QSurface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "format", "()Lio/qt/gui/QSurfaceFormat;", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "size", "()Lio/qt/core/QSize;", FunctionInfo::Abstract),
        FunctionInfo(/* 2 */ "surfaceType", "()Lio/qt/gui/QSurface$SurfaceType;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QSurface, {
    });
// END: function table

    registerMetaObject(typeId, QSurface::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSurface);
    registerSizeOfShell(typeId, sizeof(QSurface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QSurface* _object = dynamic_cast<QSurface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QSurface *object = reinterpret_cast<QSurface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QSurface *object = reinterpret_cast<const QSurface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QSurface::SurfaceClass>("QSurface::SurfaceClass", "io/qt/gui/QSurface$SurfaceClass");
    registerEnumTypeInfo<QSurface::SurfaceType>("QSurface::SurfaceType", "io/qt/gui/QSurface$SurfaceType");
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiGui/QSurface_shell.cpp <==
#include "QSurface_shell.h"
#include <QtJambi/Cast>

void deleter_QSurface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSurface")
    QSurface *_ptr = reinterpret_cast<QSurface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSurface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSurface_shell) ); }

jmethodID QSurface_oshell::__shell_javaMethod(int pos) const { return QSurface_shell::__shell()->javaMethod(typeid(QSurface), pos); }

// emitting (writeShellDestructor)
QSurface_shell::~QSurface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSurface::~QSurface()", this)
    QSurface_shell::__shell()->destructed(typeid(QSurface));
}

// emitting (writeShellConstructor)
void QSurface_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSurface_oshell*>(ptr)->QSurface_oshell::__shell()->tryDeleteShell(typeid(QSurface));
}

// emitting Virtual overrides (virtualFunctions)
QSurfaceFormat QSurface_oshell::format() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QSurfaceFormat  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QSurface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = qtjambi_cast<QSurfaceFormat>(__jni_env, __java_return_value);
                } else {
                    QSurface_shell::__shell()->warnForMethod("QSurface::format()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QSurface::format()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSurfaceFormat();
        }
    }else{
        return QSurfaceFormat();
    }
}

QSize QSurface_oshell::size() const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QSize  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QSurface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = qtjambi_cast<QSize>(__jni_env, __java_return_value);
                } else {
                    QSurface_shell::__shell()->warnForMethod("QSurface::size()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QSurface::size()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSize();
        }
    }else{
        return QSize();
    }
}

QSurface::SurfaceType QSurface_oshell::surfaceType() const
{
    if(jmethodID method_id = __shell_javaMethod(2)){
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QSurface::SurfaceType  __qt_return_value = QSurface::SurfaceType(0);
            QTJAMBI_TRY {
                if(jobject __java_this = QSurface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = qtjambi_cast<QSurface::SurfaceType>(__jni_env, __java_return_value);
                } else {
                    QSurface_shell::__shell()->warnForMethod("QSurface::surfaceType()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QSurface::surfaceType()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSurface::SurfaceType(0);
        }
    }else{
        return QSurface::SurfaceType(0);
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QSurface_access::__qt_format_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QSurface::format() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QSurface::format() const.";
    } else {
        QSurfaceFormat __qt_return_value = format();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

jobject QSurface_access::__qt_size_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QSurface::size() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QSurface::size() const.";
    } else {
        QSize __qt_return_value = size();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

jint QSurface_access::__qt_surfaceType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QSurface::surfaceType() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QSurface::surfaceType() const.";
    } else {
        QSurface::SurfaceType __qt_return_value = surfaceType();
        return __qt_return_value;
    }
}

// emitting (writeConstructors)
// destruct QSurface_shell
void __qt_destruct_QSurface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSurface")
    reinterpret_cast<QSurface_shell*>(ptr)->~QSurface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSurface::supportsOpenGL()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QSurface_00024Impl_supportsOpenGL_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QSurface *__qt_this = QtJambiAPI::interfaceFromNativeId<QSurface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSurface::supportsOpenGL()const", __this_nativeId)
        __java_return_value = __qt_this->QSurface::supportsOpenGL();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSurface::format()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QSurface_00024Impl_00024ConcreteWrapper_format_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSurface *__qt_this = QtJambiAPI::interfaceFromNativeId<QSurface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSurface::format()const", __this_nativeId)
        __java_return_value = static_cast<const QSurface_access*>(__qt_this)->__qt_format_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSurface::size()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QSurface_00024Impl_00024ConcreteWrapper_size_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSurface *__qt_this = QtJambiAPI::interfaceFromNativeId<QSurface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSurface::size()const", __this_nativeId)
        __java_return_value = static_cast<const QSurface_access*>(__qt_this)->__qt_size_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSurface::surfaceType()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QSurface_00024Impl_00024ConcreteWrapper_surfaceType_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QSurface *__qt_this = QtJambiAPI::interfaceFromNativeId<QSurface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSurface::surfaceType()const", __this_nativeId)
        __java_return_value = static_cast<const QSurface_access*>(__qt_this)->__qt_surfaceType_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSurface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QSurface>("QSurface", "io/qt/gui/QSurface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "format", "()Lio/qt/gui/QSurfaceFormat;", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "size", "()Lio/qt/core/QSize;", FunctionInfo::Abstract),
        FunctionInfo(/* 2 */ "surfaceType", "()Lio/qt/gui/QSurface$SurfaceType;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QSurface, {
    });
// END: function table

    registerMetaObject(typeId, QSurface::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSurface);
    registerSizeOfShell(typeId, sizeof(QSurface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QSurface* _object = dynamic_cast<QSurface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QSurface *object = reinterpret_cast<QSurface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QSurface *object = reinterpret_cast<const QSurface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QSurface::SurfaceClass>("QSurface::SurfaceClass", "io/qt/gui/QSurface$SurfaceClass");
    registerEnumTypeInfo<QSurface::SurfaceType>("QSurface::SurfaceType", "io/qt/gui/QSurface$SurfaceType");
// END: enums and flags
}
